;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "cond-let" "20251019.2020"
  "Additional and improved binding conditionals."
  '((emacs "28.1"))
  :url "https://github.com/tarsius/cond-let"
  :commit "09ebf1caa81c99677ce74091a23b48a28d53bcd9"
  :revdesc "09ebf1caa81c"
  :keywords '("extensions"))
